Class: Rack::MaintenanceMode::Railtie
- Inherits:
-
Rails::Railtie
- Object
- Rails::Railtie
- Rack::MaintenanceMode::Railtie
- Defined in:
- lib/rack/maintenance_mode/railtie.rb
Overview
This is the primary integration point when using this gem within a Rails application. This railtie allows for the following customizations:
config.maintenance_mode.if - used for overriding the logic to determine
whether or not the application is in maintenance mode.
config.maintenance_mode.response - used for generating the maintenance
response for the client when in maintenance mode.